@@ -1,5 +1,5 @@
-import os
 import datetime
+import os
 import random
 
 import pandas as pd
@@ -14,10 +14,9 @@ import numpy as np
 from datetime import timedelta
 
 from sklearn.metrics import roc_auc_score as roc_auc
-from fedot.core.chains.chain import Chain
+from fedot.core.pipelines.pipeline import Pipeline
 from fedot.core.composer.gp_composer.gp_composer import \
     GPComposerBuilder, GPComposerRequirements
-from fedot.core.composer.visualisation import ChainVisualiser
 from fedot.core.data.data import InputData
 from fedot.core.repository.operation_types_repository import OperationTypesRepository
 from fedot.core.repository.quality_metrics_repository import \
@@ -60,7 +59,7 @@ def get_model(train_file_path: str, cur_lead_time: datetime.timedelta = timedelt
     dataset_to_compose = InputData.from_csv(train_file_path, task=task)
 
     # the search of the models provided by the framework
-    # that can be used as nodes in a chain for the selected task
+    # that can be used as nodes in a pipeline for the selected task
     models_repo = OperationTypesRepository()
     available_model_types, _ = models_repo.suitable_operation(task_type=task.task_type, tags=['simple'])
 
@@ -68,7 +67,7 @@ def get_model(train_file_path: str, cur_lead_time: datetime.timedelta = timedelt
 
     composer_requirements = GPComposerRequirements(
         primary=available_model_types, secondary=available_model_types,
-        max_lead_time=cur_lead_time)
+        timeout=cur_lead_time)
 
     # Create the genetic programming-based composer, that allow to find
     # the optimal structure of the composite model
@@ -76,21 +75,21 @@ def get_model(train_file_path: str, cur_lead_time: datetime.timedelta = timedelt
     composer = builder.build()
 
     # run the search of best suitable model
-    chain_evo_composed = composer.compose_chain(data=dataset_to_compose, is_visualise=False)
-    chain_evo_composed.fit(input_data=dataset_to_compose)
+    pipeline_evo_composed = composer.compose_pipeline(data=dataset_to_compose, is_visualise=False)
+    pipeline_evo_composed.fit(input_data=dataset_to_compose)
 
-    return chain_evo_composed
+    return pipeline_evo_composed
 
 
-def apply_model_to_data(model: Chain, data_path: str):
+def apply_model_to_data(model: Pipeline, data_path: str):
     df, file_path = create_multi_clf_examples_from_excel(data_path, return_df=True)
-    dataset_to_apply = InputData.from_csv(file_path, target_column=None)
+    dataset_to_apply = InputData.from_csv(file_path, target_columns=None)
     evo_predicted = model.predict(dataset_to_apply)
     df['forecast'] = probs_to_labels(evo_predicted.predict)
     return df
 
 
-def validate_model_quality(model: Chain, data_path: str):
+def validate_model_quality(model: Pipeline, data_path: str):
     dataset_to_validate = InputData.from_csv(data_path)
     predicted_labels = model.predict(dataset_to_validate).predict
 
@@ -111,8 +110,7 @@ if __name__ == '__main__':
 
     fitted_model = get_model(train_file_path)
 
-    visualiser = ChainVisualiser()
-    visualiser.visualise(fitted_model)
+    fitted_model.show()
 
     roc_auc = validate_model_quality(fitted_model, test_file_path)
     print(f'ROC AUC metric is {roc_auc}')
