@@ -20,11 +20,11 @@ from fedot.core.optimisers.gp_comp.gp_optimiser import GPGraphOptimiser, GPGraph
     GraphGenerationParams
 from fedot.core.optimisers.gp_comp.operators.inheritance import GeneticSchemeTypesEnum
 from fedot.core.optimisers.gp_comp.operators.mutation import MutationStrengthEnum, single_add_mutation, \
-    single_change_mutation, single_drop_mutation, single_edge_mutation
+    single_change_mutation, single_drop_mutation, single_edge_mutation, MutationTypesEnum
 from fedot.core.optimisers.gp_comp.operators.regularization import RegularizationTypesEnum
 from fedot.core.optimisers.gp_comp.param_free_gp_optimiser import GPGraphParameterFreeOptimiser
 from fedot.core.pipelines.pipeline import Pipeline
-from fedot.core.pipelines.validation import validate
+from fedot.core.pipelines.validation import validate, ts_rules, common_rules
 from fedot.core.repository.operation_types_repository import OperationTypesRepository, get_operations_for_task
 from fedot.core.repository.quality_metrics_repository import (ClassificationMetricsEnum, MetricsEnum,
                                                               MetricsRepository, RegressionMetricsEnum)
@@ -111,12 +111,20 @@ class GPComposer(Composer):
 
         self.optimiser.graph_generation_params.advisor.task = data.task
 
+        if data.task == TaskTypesEnum.ts_forecasting:
+            self.optimiser.graph_generation_params.rules_for_constraint = ts_rules + common_rules
+        else:
+            self.optimiser.graph_generation_params.rules_for_constraint = common_rules
+
         if self.composer_requirements.max_pipeline_fit_time:
             set_multiprocess_start_method()
 
         if not self.optimiser:
             raise AttributeError(f'Optimiser for graph composition is not defined')
 
+        # shuffle data if necessary
+        data.shuffle()
+
         if self.composer_requirements.cv_folds is not None:
             objective_function_for_pipeline = self._cv_validation_metric_build(data)
         else:
@@ -301,9 +309,10 @@ class GPComposerBuilder:
 
         if self.optimiser_parameters.mutation_types is None:
             self.optimiser_parameters.mutation_types = [boosting_mutation, parameter_change_mutation,
-                                                        single_edge_mutation, single_change_mutation,
-                                                        single_drop_mutation,
-                                                        single_add_mutation]
+                                                        MutationTypesEnum.single_edge,
+                                                        MutationTypesEnum.single_change,
+                                                        MutationTypesEnum.single_drop,
+                                                        MutationTypesEnum.single_add]
 
         optimiser = optimiser_type(initial_graph=self._composer.initial_pipeline,
                                    requirements=self._composer.composer_requirements,
