@@ -2,6 +2,8 @@ from copy import copy
 from datetime import timedelta
 from multiprocessing import Manager, Process
 from typing import Callable, List, Optional, Tuple, Union
+import pandas as pd
+import numpy as np
 
 from fedot.core.composer.cache import OperationsCache
 from fedot.core.dag.graph import Graph
@@ -15,7 +17,13 @@ from fedot.core.optimisers.utils.population_utils import input_data_characterist
 from fedot.core.pipelines.node import Node, PrimaryNode
 from fedot.core.pipelines.template import PipelineTemplate
 from fedot.core.pipelines.tuning.unified import PipelineTuner
+from fedot.core.data.data import data_type_is_table
 
+# The allowed empirical partition limit of the number of rows to delete.
+# Rows that have 'string' type, instead of other 'integer' observes.
+# Example: 90% objects in column are 'integer', other are 'string'. Then
+# we will try to convert 'string' data to 'integer', otherwise delete it.
+EMPIRICAL_PARTITION = 0.1
 ERROR_PREFIX = 'Invalid pipeline configuration:'
 
 
@@ -54,7 +62,7 @@ class Pipeline(Graph):
         :param input_data: data used for operation training
         """
         # Clean all saved states and fit all operations
-        self.log.info('Fit pipeline from scratch')
+        self.log.debug('Fit pipeline from scratch')
         self.unfit()
         self.fit(input_data, use_fitted=False)
 
@@ -179,6 +187,8 @@ class Pipeline(Graph):
     def _preprocessing_fit_data(self, data: Union[InputData, MultiModalData]):
         has_imputation_operation, has_encoder_operation = pipeline_encoders_validation(self)
 
+        data = _custom_preprocessing(data)
+
         if data_has_missing_values(data) and not has_imputation_operation:
             data = _imputation_implementation(data)
 
@@ -223,23 +233,25 @@ class Pipeline(Graph):
             self.log.error(ex)
             raise ValueError(ex)
 
-        has_imputation_operation, has_encoder_operation = pipeline_encoders_validation(self)
-
-        if data_has_missing_values(input_data) and not has_imputation_operation:
-            input_data = _imputation_implementation(input_data)
-
-        if data_has_categorical_features(input_data) and not has_encoder_operation:
-            _encode_data_for_prediction(input_data, self.pre_proc_encoders)
-
         # Make copy of the input data to avoid performing inplace operations
         copied_input_data = copy(input_data)
+        has_imputation_operation, has_encoder_operation = pipeline_encoders_validation(self)
+
+        copied_input_data = _custom_preprocessing(copied_input_data)
+
+        if data_has_missing_values(copied_input_data) and not has_imputation_operation:
+            copied_input_data = _imputation_implementation(copied_input_data)
+
+        if data_has_categorical_features(copied_input_data) and not has_encoder_operation:
+            _encode_data_for_prediction(copied_input_data, self.pre_proc_encoders)
+
         copied_input_data = self._assign_data_to_nodes(copied_input_data)
 
         result = self.root_node.predict(input_data=copied_input_data, output_mode=output_mode)
         return result
 
     def fine_tune_all_nodes(self, loss_function: Callable,
-                            loss_params: Callable = None,
+                            loss_params: dict = None,
                             input_data: Union[InputData, MultiModalData] = None,
                             iterations=50, timeout: int = 5,
                             cv_folds: int = None,
@@ -256,7 +268,7 @@ class Pipeline(Graph):
                                        task=copied_input_data.task,
                                        iterations=iterations,
                                        timeout=timeout)
-        self.log.info('Start tuning of primary nodes')
+        self.log.info('Start pipeline tuning')
 
         tuned_pipeline = pipeline_tuner.tune_pipeline(input_data=copied_input_data,
                                                       loss_function=loss_function,
@@ -274,8 +286,7 @@ class Pipeline(Graph):
         :param path to json file with operation
         :return: json containing a composite operation description
         """
-        if not self.template:
-            self.template = PipelineTemplate(self, self.log)
+        self.template = PipelineTemplate(self, self.log)
         json_object, dict_fitted_operations = self.template.export_pipeline(path, root_node=self.root_node)
         return json_object, dict_fitted_operations
 
@@ -327,7 +338,7 @@ class Pipeline(Graph):
         print('Pipeline structure:')
         print(self.__str__())
         for node in self.nodes:
-            print(f'{node.operation.operation_type} - {node.custom_params}')
+            print(f"{node.operation.operation_type} - {node.custom_params}")
 
 
 def pipeline_encoders_validation(pipeline: Pipeline) -> (bool, bool):
@@ -368,6 +379,82 @@ def pipeline_encoders_validation(pipeline: Pipeline) -> (bool, bool):
     return has_imputer, has_encoder
 
 
+def _is_numeric(s) -> bool:
+    """ Check if variable converted to float.
+
+    :param s: any type variable
+    :return: is variable convertable to float
+    """
+    try:
+        float(s)
+        return True
+    except ValueError:
+        return False
+
+
+def is_np_array_has_nan(array):
+    for x in array:
+        if x is np.nan:
+            return True
+    return False
+
+
+def _try_convert_to_numeric(values):
+    try:
+        values = pd.to_numeric(values)
+        values = values.astype(np.number)
+    except ValueError:
+        pass
+    return values
+
+
+def _custom_preprocessing(data: Union[InputData, MultiModalData]):
+    if isinstance(data, InputData):
+        if data_type_is_table(data):
+            data = _preprocessing_input_data(data)
+    elif isinstance(data, MultiModalData):
+        for data_source_name, values in data.items():
+            if data_type_is_table(values):
+                data[data_source_name] = _preprocessing_input_data(values)
+
+    return data
+
+
+def _preprocessing_input_data(data: InputData) -> InputData:
+    features = data.features
+    target = data.target
+
+    # delete rows with equal target None
+    if target is not None and len(target.shape) != 0 and is_np_array_has_nan(target):
+        target_index_with_nan = np.hstack(np.argwhere(np.isnan(target)))
+        data.features = np.delete(features, target_index_with_nan, 0)
+        data.target = np.delete(data.target, target_index_with_nan, 0)
+        data.idx = np.delete(data.idx, target_index_with_nan, 0)
+
+    source_shape = features.shape
+    columns_amount = source_shape[1] if len(source_shape) > 1 else 1
+
+    for i in range(columns_amount):
+        values = pd.Series(features[:, i])
+        # check for each column, if values converted to numeric. remember index of rows that not converted
+        if any(list(map(lambda x: isinstance(x, str), values))):
+            not_numeric = list(map(lambda x: not _is_numeric(x), values))
+            rows_to_nan = list(values.index[not_numeric])
+            partition_not_numeric = len(rows_to_nan) / source_shape[0]
+
+            # if partition of numerical rows less then EMPIRICAL_PARTITION,
+            # then convert to numerical and others to Nan
+            if partition_not_numeric < EMPIRICAL_PARTITION:
+                values[rows_to_nan] = np.nan
+                data.features[:, i] = _try_convert_to_numeric(values)
+            # if EMPIRICAL_PARTITION < partition < 1, then some data in column are
+            # integer and some data are string, can not handle this case
+            elif partition_not_numeric < 0.9:
+                raise ValueError("The data in the column has a different type. Need to preprocessing data manually.")
+
+    return data
+
+
 def nodes_with_operation(pipeline: Pipeline, operation_name: str) -> list:
     """ The function return list with nodes with the needed operation
 
@@ -410,13 +497,19 @@ def _encode_data_for_fit(data: Union[InputData, MultiModalData]) -> \
 
 def _encode_data_for_prediction(data: Union[InputData, MultiModalData],
                                 encoders: Union[dict, DataOperationImplementation]):
-    if isinstance(data, InputData):
-        transformed = encoders.transform(data, True).predict
-        data.features = transformed
-    elif isinstance(data, MultiModalData):
-        for data_source_name, encoder in encoders.items():
-            transformed = encoder.transform(data[data_source_name], True).predict
-            data[data_source_name].features = transformed
+    """ Transformation the prediction data inplace. Use the same transformations as for the training data.
+
+    :param data: data to transformation
+    :param encoders: encoders f transformation
+    """
+    if encoders:
+        if isinstance(data, InputData):
+            transformed = encoders.transform(data, True).predict
+            data.features = transformed
+        elif isinstance(data, MultiModalData):
+            for data_source_name, encoder in encoders.items():
+                transformed = encoder.transform(data[data_source_name], True).predict
+                data[data_source_name].features = transformed
 
 
 def _imputation_implementation(data: Union[InputData, MultiModalData]) -> Union[InputData, MultiModalData]:
@@ -431,6 +524,10 @@ def _imputation_implementation(data: Union[InputData, MultiModalData]) -> Union[
 
 
 def _imputation_implementation_unidata(data: InputData):
+    """ Fill in the gaps in the data inplace.
+
+    :param data: data for fill in the gaps
+    """
     imputer = ImputationImplementation()
     output_data = imputer.fit_transform(data)
     transformed = InputData(features=output_data.predict, data_type=output_data.data_type,
